==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebCheckboxBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescriptionMetadata } from "./WebComponentBoolValueChangedEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebCheckboxBaseDescription } from "./WebCheckboxBaseDescription";
/**
 * @hidden
 */
export let WebCheckboxBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCheckboxBaseDescriptionMetadata extends Base {
        static b(a) {
            if (WebCheckboxBaseDescriptionMetadata.a == null) {
                WebCheckboxBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCheckboxBaseDescriptionMetadata.c(WebCheckboxBaseDescriptionMetadata.a);
            }
            if (a.k(WebCheckboxBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCheckboxBaseDescriptionMetadata.a);
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.d(a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CheckboxBase");
            a.item("__tagNameWC", "String:igc-checkbox-base");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "String");
            a.item("Checked", "Boolean");
            a.item("LabelPosition", "ExportedType:string:CheckboxBaseLabelPosition");
            a.item("LabelPosition@stringUnion", "WebComponents;React");
            a.item("LabelPosition@names", "Before;After");
            a.item("Disabled", "Boolean");
            a.item("Required", "Boolean");
            a.item("Name", "String");
            a.item("Invalid", "Boolean");
            a.item("ChangeRef", "EventRef::change");
            a.item("FocusRef", "EventRef::focus");
            a.item("BlurRef", "EventRef::blur");
        }
        static d(a) {
            WebCheckboxBaseDescriptionMetadata.b(a);
            a.ad("WebCheckboxBase", () => new WebCheckboxBaseDescription());
            a.ac("WebCheckboxBase", WebCheckboxBaseDescriptionMetadata.a);
        }
    }
    WebCheckboxBaseDescriptionMetadata.$t = markType(WebCheckboxBaseDescriptionMetadata, 'WebCheckboxBaseDescriptionMetadata');
    WebCheckboxBaseDescriptionMetadata.a = null;
    return WebCheckboxBaseDescriptionMetadata;
})();

==> igniteui-angular-core-19.0.1.tgz: package/esm2015/lib/WebCheckboxBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxChangeEventArgsDescriptionMetadata } from "./WebCheckboxChangeEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebCheckboxBaseDescription } from "./WebCheckboxBaseDescription";
/**
 * @hidden
 */
export let WebCheckboxBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCheckboxBaseDescriptionMetadata extends Base {
        static b(a) {
            if (WebCheckboxBaseDescriptionMetadata.a == null) {
                WebCheckboxBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCheckboxBaseDescriptionMetadata.c(WebCheckboxBaseDescriptionMetadata.a);
            }
            if (a.k(WebCheckboxBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCheckboxBaseDescriptionMetadata.a);
            WebCheckboxChangeEventArgsDescriptionMetadata.d(a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CheckboxBase");
            a.item("__tagNameWC", "String:igc-checkbox-base");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "String");
            a.item("Checked", "Boolean");
            a.item("LabelPosition", "ExportedType:string:CheckboxBaseLabelPosition");
            a.item("LabelPosition@stringUnion", "WebComponents;React");
            a.item("LabelPosition@names", "After;Before");
            a.item("Disabled", "Boolean");
            a.item("Required", "Boolean");
            a.item("DefaultChecked", "Boolean");
            a.item("Name", "String");
            a.item("Invalid", "Boolean");
            a.item("ChangeRef", "EventRef::change");
            a.item("FocusRef", "EventRef::focus:skipWCPrefix");
            a.item("BlurRef", "EventRef::blur:skipWCPrefix");
        }
        static d(a) {
            WebCheckboxBaseDescriptionMetadata.b(a);
            a.ae("WebCheckboxBase", () => new WebCheckboxBaseDescription());
            a.ad("WebCheckboxBase", WebCheckboxBaseDescriptionMetadata.a);
        }
    }
    WebCheckboxBaseDescriptionMetadata.$t = markType(WebCheckboxBaseDescriptionMetadata, 'WebCheckboxBaseDescriptionMetadata');
    WebCheckboxBaseDescriptionMetadata.a = null;
    return WebCheckboxBaseDescriptionMetadata;
})();
